# massprince package

A Python package containing basic math utilities.

## Installation

You can install the package using pip:

## Usage

The package provides the following functions:

* `floor(a, b)`: Returns the floor division of `a` by `b`.
* `pow(a, b)`: Returns the value of `a` raised to the power of `b`.
* `add(a, b)`: Returns the sum of `a` and `b`.
* `sub(a, b)`: Returns the difference of `a` and `b`.
* `mul(a, b)`: Returns the product of `a` and `b`.
* `div(a, b)`: Returns the division of `a` by `b`.
* `mod(a, b)`: Returns the remainder of the division of `a` by `b`.

and also it will calls the mass_prince functin also 